@@ -7,10 +7,12 @@ log = logging.getLogger('server')
 
 class AdminWorker(BaseWorker):
     async def start(self):
-        await self.send_service_message({
-            '_': 'hello',
-            'version': 1,
-        })
+        await self.send_service_message(
+            {
+                '_': 'hello',
+                'version': 1,
+            }
+        )
         msg = await self.recv_service_message()
         if msg.get('_') == 'authorize-client':
             token = msg.get('token')
